pub enum Tool {
Ar,
As,
Cov,
Lld,
Nm,
Objcopy,
Objdump,
Profdata,
Readobj,
Size,
Strip,
}Variants
Implementations
Sourceimpl Tool
impl Tool
pub fn name(self) -> &'static str
pub fn exe(self) -> String
pub fn path(self) -> Result<PathBuf>
Sourcepub fn rust_exec(self) -> !
pub fn rust_exec(self) -> !
Forwards execution to the specified tool. If the tool fails to start or is not found this process exits with status code 101 the same as if the process has a panic!
Sourcepub fn cargo_exec(self, examples: Option<&str>) -> !
pub fn cargo_exec(self, examples: Option<&str>) -> !
Parses arguments for cargo $tool and then if needed executes cargo build
before parsing the required arguments to rust-$tool.
If the tool fails to start or is not found this process exits with
status code 101 the same as if the process has a panic!
pub fn needs_build(self) -> bool