Enum cargo_binutils::Tool[][src]

pub enum Tool {
    Ar,
    Cov,
    Lld,
    Nm,
    Objcopy,
    Objdump,
    Profdata,
    Readobj,
    Size,
    Strip,
}

Variants

Ar
Cov
Lld
Nm
Objcopy
Objdump
Profdata
Readobj
Size
Strip

Implementations

Forwards execution to the specified tool. If the tool fails to start or is not found this process exits with status code 101 the same as if the process has a panic!

Parses arguments for cargo $tool and then if needed executes cargo build before parsing the required arguments to rust-$tool. If the tool fails to start or is not found this process exits with status code 101 the same as if the process has a panic!