[−][src]Enum cargo_binutils::Tool
Variants
Implementations
impl Tool[src]
pub fn name(self) -> &'static str[src]
pub fn exe(self) -> String[src]
pub fn path(self) -> Result<PathBuf>[src]
pub fn rust_exec(self) -> ![src]
Forwards execution to the specified tool. If the tool fails to start or is not found this process exits with status code 101 the same as if the process has a panic!
pub fn cargo_exec(self, examples: Option<&str>) -> ![src]
Parses arguments for cargo $tool and then if needed executes cargo build
before parsing the required arguments to rust-$tool.
If the tool fails to start or is not found this process exits with
status code 101 the same as if the process has a panic!
pub fn needs_build(self) -> bool[src]